@@ -21,9 +21,8 @@
 typedef std::pair<std::string, int> ShaderfileModePair;
 
 GLuint compileAndLinkShader(
-  std::vector<ShaderfileModePair> const& shaders, 
-  size_t NLights, size_t NMaterials,
-  std::vector<std::string> const& defineflags);
+  std::vector<ShaderfileModePair> const& shaders, size_t NLights,
+  size_t NMaterials, std::vector<std::string> const& defineflags);
 
 GLuint createShaders(GLchar const *src, int shaderType,
                      std::string const& filename);
